@@ -29,7 +29,8 @@ def get_args():
   args = sys.argv
   print(args)
   args.pop(0)
-  print('test-1')
+  args.pop(1)
+  print(args)
   return args
 
 def is_args_valid(args):
